/*
 * This file belongs to the XQuare distribution.
 * Copyright (C) 2003 Universite de Versailles Saint-Quentin.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307.
 * You can also get it at http://www.gnu.org/licenses/lgpl.html
 * 
 * For more information on this software, see http://www.xquare.org.
 */

import org.xquark.mapping.*;
import java.sql.*;
import java.math.*;

/* SAMPLE NOTE:
 * 
 * This example shows a generic method for primary/foreign key generation.
 * This may not be the best method for your favourite database. For instance,
 * with Oracle you may prefer using a sequence.
 */

public class ProductId implements UserGenerator {
	private static int counter = -1;

	public String getXMLType() {
		return "int";
	}

	public synchronized Object getValue(StorageContext context) {
		if (counter < 0)
			initCounter(context.getConnection());
		return new BigDecimal(++counter);
	}
    
	void initCounter(Connection connection) {
		ResultSet rs = null;
		Statement statement = null;
		try {
			statement = connection.createStatement();
			try {
				rs = statement.executeQuery("select max(\"id\") from \"product\"");
			} catch (SQLException ex) {
				rs = statement.executeQuery("select max(id) from product");
			}
			Object result = null;
			while (rs.next()) {
				counter = rs.getInt(1);
			}
		}
		catch (SQLException ex) {
			ex.printStackTrace();
		}
		finally {
			try {
				if (rs != null)
					rs.close();
				if (statement != null)
					statement.close();
			}
			catch (SQLException ex) {
				// no op
			}
		}
	}
}
